==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaSkalaOcenyKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaSkalaOcenyKey extends GenericDPSObject {
    /**
     * DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long skalaOcenyId;

    /**
     * DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

    /**
     * DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaSkalaOcenyKey other = (DiagnozaSkalaOcenyKey) that;
        return (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaSkalaOcenyKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaSkalaOcenyKey extends GenericDPSObject {
    /**
     * DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long skalaOcenyId;

    /**
     * DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSkalaOcenyId() {
        return skalaOcenyId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_SKALA_OCENY.SKALA_OCENY_ID
     *
     * @param skalaOcenyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkalaOcenyId(Long skalaOcenyId) {
        this.skalaOcenyId = skalaOcenyId;
    }

    /**
     * @return DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaId() {
        return diagnozaId;
    }

    /**
     * DIAGNOZA_SKALA_OCENY.DIAGNOZA_ID
     *
     * @param diagnozaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaId(Long diagnozaId) {
        this.diagnozaId = diagnozaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaSkalaOcenyKey other = (DiagnozaSkalaOcenyKey) that;
        return (this.getSkalaOcenyId() == null ? other.getSkalaOcenyId() == null : this.getSkalaOcenyId().equals(other.getSkalaOcenyId()))
            && (this.getDiagnozaId() == null ? other.getDiagnozaId() == null : this.getDiagnozaId().equals(other.getDiagnozaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getSkalaOcenyId() == null) ? 0 : getSkalaOcenyId().hashCode());
        result = prime * result + ((getDiagnozaId() == null) ? 0 : getDiagnozaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", skalaOcenyId=").append(skalaOcenyId);
        sb.append(", diagnozaId=").append(diagnozaId);
        sb.append("]");
        return sb.toString();
    }
}
